"""Metadata for PyMaple package"""

__pkgname__ = "PyMaple"
__version__ = "2.0"
__authors__ = "Akash Dhruv"
__license__ = "MIT License"
__copyright__ = "Copyright (c) Akash Dhruv 2021. All Rights Reserved."
__description__ = "Maple Container Utility"
